%define _disable_ld_no_undefined 1
%define evtlog_ver  0.2.12

%define major 3.9
%define libname %mklibname syslog-ng %{major}
%define develname %mklibname syslog-ng -d

%define journalcfgdir %{_sysconfdir}/systemd

Name:       syslog-ng
Version:    3.9.1
Release:    %mkrel 1
Summary:    Syslog-ng daemon
Group:      System/Kernel and hardware
License:    GPLv2 LGPLv2+
Url:        http://www.balabit.com/products/syslog_ng/
Source0:    http://www.balabit.com/downloads/files/syslog-ng/open-source-edition/%{version}/source/%{name}-%{version}.tar.gz
Source1:    https://www.balabit.com/documents/syslog-ng-ose-3.9-guides/en/syslog-ng-ose-guide-admin/pdf/syslog-ng-ose-guide-admin.pdf
Source2:    syslog-ng.sysconfig
Source3:    syslog-ng.conf
Source4:    syslog-ng.logrotate
Source5:    syslog-ng.tmpfiles
# (eatdirt) script to switch on fwd to syslog in systemd journal
Source6:    syslog-ng_switchfwd
BuildRequires:  flex
BuildRequires:  bison
BuildRequires:  xsltproc
BuildRequires:  eventlog-devel >= %{evtlog_ver}
BuildRequires:  net-devel >= 1.1.3
BuildRequires:  glib2-devel
BuildRequires:  libwrap-devel
BuildRequires:  openssl-devel
BuildRequires:  dbi-devel
BuildRequires:  cap-devel
BuildRequires:  geoip-devel 
BuildRequires:  libjson-devel
BuildRequires:  libesmtp-devel
BuildRequires:  systemd-devel
BuildRequires:  python-devel
Provides:       syslog-daemon
Requires:       %{libname} = %{version}-%{release}
Requires(post):  systemd >= %{systemd_required_version}
Requires(post):  rpm-helper >= 0.24.8-1
Requires(preun): rpm-helper >= 0.24.8-1

%description
Syslog-ng is a flexible and highly scalable system logging application
that is ideal for creating centralized and trusted logging solutions.
Syslog-ng enables you to send the log messages of your hosts to remote
servers using the latest protocol standards : TCP, TLS, X.509 certificates.
Syslog-ng is able to store log messages in the most popular databases :
MySQL, PostgreSQL SQLite, Oracle and MSSQL. Syslog-ng can sort the incoming
log messages based on their content and various parameters like the source
host, application, and priority. Directories, files and database tables can
be created dynamically using macros. Complex filtering using regular
expressions and boolean operators offers almost unlimited flexibility to
forward only the important log messages to the selected destinations.

%package -n %{libname}
Summary:        Libraries for %{name}
Group:          Development/C

%description -n %{libname}
The libraries for %{name}.

%package -n %develname
Summary:        Development files for %{name}
Group:          Development/C
Provides:       %{name}-devel
Requires:       %{libname} = %{version}-%{release}

%description -n %develname
This package contains libraries and header files for
developing applications that use %{name}.

%package -n python-syslog-ng
Summary:        Python bindings for %{name}
Group:          Development/Python

%description -n python-syslog-ng
Python bindings for %{name}.

%prep
%setup -q -n %{name}-%{version}

cp %{SOURCE1} .

%build
%configure2_5x \
    --prefix=%{_prefix} \
    --sysconfdir=%{_sysconfdir}/%{name} \
    --localstatedir=%{_localstatedir}/lib/%{name} \
    --datadir=%{_datadir}/%{name} \
    --with-module-dir=/%{_libdir}/%{name} \
    --with-pidfile-dir=/run/syslog-ng \
    --with-systemdsystemunitdir=%{_unitdir} \
    --enable-ipv6 \
    --enable-linux-caps \
    --disable-pacct \
    --enable-spoof-source \
    --enable-ssl \
    --enable-tcp-wrapper \
    --enable-shared \
    --disable-static \
    --enable-dynamic-linking \
    --enable-systemd \
    --enable-manpages
     # --enable-env-wrapper \
%make_build

%install
%make_install

install -m 644 %{SOURCE3} %{buildroot}%{_sysconfdir}/syslog-ng/syslog-ng.conf
install -d -m 755 %{buildroot}%{_sysconfdir}/syslog-ng/conf.d
install -d -m 755 %{buildroot}%{_sysconfdir}/syslog-ng/patterndb.d

install -D -m 644 %{SOURCE2} %{buildroot}%{_sysconfdir}/sysconfig/syslog-ng

install -D -m 644 %{SOURCE4} %{buildroot}%{_sysconfdir}/logrotate.d/syslog-ng

install -D -m 644 %{SOURCE5} %{buildroot}%{_tmpfilesdir}/%{name}.conf

install -d -m 755 %{buildroot}%{_localstatedir}/lib/syslog-ng

# install the ld.so conf file
install -d -m 755 %{buildroot}%{_sysconfdir}/ld.so.conf.d/
cat > %{buildroot}%{_sysconfdir}/ld.so.conf.d/%{name}.conf <<EOF
%{_libdir}/%{name}
EOF

# (eatdirt)
%__install -D -p -m 755 %{SOURCE6} %{buildroot}%{_sbindir}/syslog-ng_switchfwd

rm -f %{buildroot}%{_libdir}/*.la
rm -f %{buildroot}%{_libdir}/*.a

%post

#(eatdirt)
# switch ForwardToSyslog=yes in /etc/systemd/journald.conf + backup
%{_sbindir}/syslog-ng_switchfwd %{journalcfgdir} on
# restart systemd-journal
/bin/systemctl try-restart systemd-journald || :

%_tmpfilescreate %{name}
%_post_service %{name}
# (cg) Handle a quirk of syslog service installations
if [ -f %{_sysconfdir}/systemd/system/multi-user.target.wants/%{name}.service -a ! -f %{_sysconfdir}/systemd/system/syslog.service ]; then
  cp -a %{_sysconfdir}/systemd/system/multi-user.target.wants/%{name}.service %{_sysconfdir}/systemd/system/syslog.service
fi

%preun
%_preun_service %{name}

#(eatdirt)
#restore the previously saved /etc/systemd/journald.conf file
%{_sbindir}/syslog-ng_switchfwd %{journalcfgdir} off
# restart systemd-journal
/bin/systemctl try-restart systemd-journald || :


%files
%doc AUTHORS COPYING VERSION NEWS.md CONTRIBUTING.md
%doc doc/security doc/xsd
%doc syslog-ng-ose-guide-admin.pdf
%dir %{_sysconfdir}/syslog-ng
%dir %{_sysconfdir}/syslog-ng/conf.d
%dir %{_sysconfdir}/syslog-ng/patterndb.d
%config(noreplace) %{_sysconfdir}/syslog-ng/syslog-ng.conf
%config(noreplace) %{_sysconfdir}/syslog-ng/scl.conf
%config(noreplace) %{_sysconfdir}/sysconfig/syslog-ng
%config(noreplace) %{_sysconfdir}/logrotate.d/syslog-ng
%{_unitdir}/syslog-ng.service
%{_tmpfilesdir}/%{name}.conf
%{_sysconfdir}/ld.so.conf.d/%{name}.conf
%{_sbindir}/syslog-ng
%{_sbindir}/syslog-ng-ctl
# (eatdirt)
%{_sbindir}/syslog-ng_switchfwd
%{_libdir}/syslog-ng
%{_bindir}/loggen
%{_bindir}/pdbtool
%{_bindir}/dqtool
%{_bindir}/update-patterndb
%{_datadir}/syslog-ng
%{_mandir}/man1/pdbtool.1*
%{_mandir}/man1/loggen.1*
%{_mandir}/man1/syslog-ng-ctl.1*
%{_mandir}/man5/syslog-ng.conf.5*
%{_mandir}/man8/syslog-ng.8*
%{_localstatedir}/lib/syslog-ng

%files -n %{libname}
%{_libdir}/libsyslog-ng-%{major}.so.*

%files -n %{develname}
%{_libdir}/libsyslog-ng.so
%{_libdir}/pkgconfig/syslog-ng.pc
%{_libdir}/pkgconfig/syslog-ng-test.pc
%{_libdir}/pkgconfig/syslog-ng-native-connector.pc
%{_libdir}/pkgconfig/syslog-ng-add-contextual-data.pc
%{_includedir}/syslog-ng

%files -n python-syslog-ng
%{python_sitelib}/syslogng
%{python_sitelib}/syslogng-1.0-py%{pyver}.egg-info


%changelog
* Sat Jan 28 2017 guillomovitch <guillomovitch> 3.9.1-1.mga6
+ Revision: 1083764
- new version 3.9.1

* Sat Aug 27 2016 guillomovitch <guillomovitch> 3.8.1-1.mga6
+ Revision: 1049192
- new version 3.8.1

* Sun Jul 24 2016 guillomovitch <guillomovitch> 3.7.3-1.mga6
+ Revision: 1043530
- new version 3.7.3

* Thu Mar 03 2016 umeabot <umeabot> 3.7.1-3.mga6
+ Revision: 984452
- Rebuild for openssl

* Fri Feb 12 2016 umeabot <umeabot> 3.7.1-2.mga6
+ Revision: 958947
- Mageia 6 Mass Rebuild

* Sun Oct 11 2015 guillomovitch <guillomovitch> 3.7.1-1.mga6
+ Revision: 889636
- new version 3.7.1

* Mon Jun 22 2015 guillomovitch <guillomovitch> 3.6.3-1.mga6
+ Revision: 839393
- new version 3.6.3

* Wed Oct 15 2014 umeabot <umeabot> 3.5.6-6.mga5
+ Revision: 744678
- Second Mageia 5 Mass Rebuild

* Wed Oct 08 2014 eatdirt <eatdirt> 3.5.6-5.mga5
+ Revision: 737448
- Adding scriptlet to switch on fwd in systemd journal

* Fri Sep 26 2014 tv <tv> 3.5.6-4.mga5
+ Revision: 725240
- rebuild for bogus file deps

* Tue Sep 16 2014 umeabot <umeabot> 3.5.6-3.mga5
+ Revision: 689662
- Mageia 5 Mass Rebuild

* Thu Sep 04 2014 colin <colin> 3.5.6-2.mga5
+ Revision: 672035
- Rebuild for new systemd

* Thu Aug 07 2014 guillomovitch <guillomovitch> 3.5.6-1.mga5
+ Revision: 660358
- new version 3.5.6

* Tue Jul 29 2014 guillomovitch <guillomovitch> 3.5.5-1.mga5
+ Revision: 657854
- new version 3.5.5

* Sun Jul 06 2014 pterjan <pterjan> 3.5.4.1-2.mga5
+ Revision: 650059
- Fix build with recent json-c

* Thu Mar 20 2014 guillomovitch <guillomovitch> 3.5.4.1-1.mga5
+ Revision: 606038
- new version 3.5.4.1

* Thu Mar 13 2014 guillomovitch <guillomovitch> 3.5.4-1.mga5
+ Revision: 602772
- new version 3.5.4

* Tue Feb 04 2014 guillomovitch <guillomovitch> 3.5.3-1.mga5
+ Revision: 580718
- new version 3.5.3

* Thu Nov 07 2013 guillomovitch <guillomovitch> 3.4.5-1.mga4
+ Revision: 549904
- new version 3.4.5

* Sat Oct 19 2013 umeabot <umeabot> 3.4.3-2.mga4
+ Revision: 532259
- Mageia 4 Mass Rebuild

* Mon Aug 19 2013 guillomovitch <guillomovitch> 3.4.3-1.mga4
+ Revision: 467620
- new version

* Thu May 23 2013 guillomovitch <guillomovitch> 3.4.1-1.mga4
+ Revision: 424808
- new version

* Sat May 11 2013 guillomovitch <guillomovitch> 3.3.8-3.mga3
+ Revision: 413002
- use systemctl in logrotate, instead of sysinit script

* Sun Mar 24 2013 colin <colin> 3.3.8-2.mga3
+ Revision: 405136
- Use tmpfiles macros and add system version to requires (mga#9302)

* Thu Feb 07 2013 guillomovitch <guillomovitch> 3.3.8-1.mga3
+ Revision: 395116
- new version
- fix default configuration file, for systemd compatibility (8944)
- ship tmpfile configuration
- drop old and doubtful pm-utils scriptlet
- use /etc/syslog-ng/conf.d for additional configuration snippets, as fedora

* Mon Jan 14 2013 umeabot <umeabot> 3.3.7-4.mga3
+ Revision: 383952
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Dec 04 2012 guillomovitch <guillomovitch> 3.3.7-3.mga3
+ Revision: 326660
- reformat default configuration file, and adapt to 3.3 syntax
- use regular installation prefix
- explicit systemd support

* Sat Dec 01 2012 fwang <fwang> 3.3.7-2.mga3
+ Revision: 323690
- rebuild for new pcre

* Thu Nov 29 2012 guillomovitch <guillomovitch> 3.3.7-1.mga3
+ Revision: 323119
- new version

* Fri Sep 14 2012 guillomovitch <guillomovitch> 3.3.6-1.mga3
+ Revision: 293884
- new version
- use /run instead of /var/run for PID file
- minor systemd service fixes

* Tue May 29 2012 guillomovitch <guillomovitch> 3.3.5-1.mga3
+ Revision: 249509
- new version
- drop sysinit support

* Sat Apr 28 2012 tmb <tmb> 3.3.4-3.mga2
+ Revision: 233870
- Require rpm-helper >= 0.24.8-1 for systemd support

* Sat Apr 21 2012 colin <colin> 3.3.4-2.mga2
+ Revision: 232391
- Ensure syslog-ng does the necessary post install magic to enable itself under systemd

* Sun Jan 22 2012 guillomovitch <guillomovitch> 3.3.4-1.mga2
+ Revision: 199666
- new version

* Tue Nov 29 2011 guillomovitch <guillomovitch> 3.3.3-1.mga2
+ Revision: 174076
- new version

* Tue Oct 11 2011 guillomovitch <guillomovitch> 3.3.1-1.mga2
+ Revision: 153982
- new version
- systemd support

  + rapsys <rapsys>
    - Add missing directory creation rights

* Thu Jun 30 2011 rapsys <rapsys> 3.2.4-1.mga2
+ Revision: 116910
- Add syslog-ng sources
- Created package structure for syslog-ng.

